@@ -10,7 +10,7 @@ use Capture::Tiny qw/capture/;
 use failures qw/module::comparison/;
 use Perl::Version;
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 has perl_path => (is => 'ro', isa => Str, default => '');
 has modules => (is => 'ro', isa => ArrayRef);
@@ -151,7 +151,7 @@ sub _module_pair
 sub _wrap_version
 {
     my $version = shift;
-    if($version && $version eq 'undef')
+    if($version && ($version eq 'undef' || $version eq 'missing'))
     {
         # this isn't perfect, in fact it may bite us.
         # I believe that undef does indicate that a module is
@@ -258,6 +258,19 @@ sub human_readable_report
 	return join "\n", @lines;
 }
 
+sub human_readable_list
+{
+    my $self = shift;
+    my $list = shift;
+
+    my @lines;
+    for my $module (keys %$list)
+    {
+        push @lines, sprintf("%-40s\t%s", $module, $list->{$module});
+    }
+    return join "\n", @lines;
+}
+
 1;
 
 __END__
@@ -272,7 +285,7 @@ Server::Module::Comparison - check perl module versions installed on servers.
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
